@@ -1,4 +1,3 @@
-/* $XFree86: xc/programs/Xserver/Xext/mbufpx.c,v 3.3 2001/07/23 13:15:44 dawes Exp $ */
 /************************************************************
 
 Copyright 1989, 1998  The Open Group
@@ -25,9 +24,6 @@ in this Software without prior written authorization from The Open Group.
 
 ********************************************************/
 
-/* $Xorg: mbufpx.c,v 1.4 2001/02/09 02:04:32 xorgcvs Exp $ */
-#define NEED_REPLIES
-#define NEED_EVENTS
 #ifdef HAVE_DIX_CONFIG_H
 #include <dix-config.h>
 #endif
@@ -94,7 +90,7 @@ pixMultibufferInit(pScreen, pMBScreen)
 	nInfo += pDepth->numVids;
     }
 
-    pInfo = (xMbufBufferInfo *) xalloc (nInfo * sizeof (xMbufBufferInfo));
+    pInfo = xalloc (nInfo * sizeof (xMbufBufferInfo));
     if (!pInfo)
 	return FALSE;
 
@@ -118,7 +114,7 @@ pixMultibufferInit(pScreen, pMBScreen)
      * Setup the devPrivate to mbufScreenRec
      */
 
-    pMBPriv = (mbufPixmapPrivPtr) xalloc(sizeof(* pMBPriv));
+    pMBPriv = xalloc(sizeof(* pMBPriv));
     if (!pMBPriv)
     {
 	xfree(pInfo);
@@ -157,7 +153,7 @@ pixCreateImageBuffers (pWin, nbuf, ids, action, hint)
     {
 	pMBBuffer = &pMBWindow->buffers[i];
 	pMBBuffer->pDrawable = (DrawablePtr)
-	    (*pScreen->CreatePixmap) (pScreen, width, height, depth);
+	    (*pScreen->CreatePixmap) (pScreen, width, height, depth, 0);
 	if (!pMBBuffer->pDrawable)
 	    break;
 
@@ -265,7 +261,7 @@ MultibufferPaintBackgroundRegion(pWin, pDrawable, pRegion)
     int nrects  = REGION_NUM_RECTS(pRegion);
     BoxPtr pbox = REGION_RECTS(pRegion);
 
-    pRects = (xRectangle *)ALLOCATE_LOCAL(nrects * sizeof(xRectangle));
+    pRects = xalloc(nrects * sizeof(xRectangle));
     if (pRects)
     {
 	int i;
@@ -277,7 +273,7 @@ MultibufferPaintBackgroundRegion(pWin, pDrawable, pRegion)
 	    pRects[i].height = pbox->y2 - pbox->y1;
 	}
 	MultibufferPaintBackgroundRectangles(pWin, pDrawable, nrects, pRects);
-	DEALLOCATE_LOCAL(pRects);
+	xfree(pRects);
     }
 }
 
@@ -544,7 +540,8 @@ pixPositionWindow (pWin, x, y)
     for (i = 0; i < pMBWindow->numMultibuffer; i++)
     {
 	pMBBuffer = &pMBWindow->buffers[i];
-	pPixmap = (*pScreen->CreatePixmap) (pScreen, width, height, pWin->drawable.depth);
+	pPixmap = (*pScreen->CreatePixmap) (pScreen, width, height, pWin->drawable.depth,
+					    CREATE_PIXMAP_USAGE_SCRATCH);
 	if (!pPixmap)
 	{
 	    (* MB_SCREEN_PRIV(pScreen)->DestroyImageBuffers)(pWin);
