@@ -52,7 +52,7 @@ Author:  Bob Scheifler, MIT X Consortium
 #define Dsin(d)	sin((double)d*(M_PI/11520.0))
 #define Dcos(d)	cos((double)d*(M_PI/11520.0))
 
-_X_EXPORT void
+void
 miFillArcSetup(xArc *arc, miFillArcRec *info)
 {
     info->y = arc->height >> 1;
@@ -304,7 +304,7 @@ miGetPieEdge(
     miGetArcEdge(arc, edge, k, top, left);
 }
 
-_X_EXPORT void
+void
 miFillArcSliceSetup(xArc *arc, miArcSliceRec *slice, GCPtr pGC)
 {
     int angle1, angle2;
@@ -546,10 +546,10 @@ miFillEllipseI(
     int *widths;
     int *wids;
 
-    points = (DDXPointPtr)xalloc(sizeof(DDXPointRec) * arc->height);
+    points = xalloc(sizeof(DDXPointRec) * arc->height);
     if (!points)
 	return;
-    widths = (int *)xalloc(sizeof(int) * arc->height);
+    widths = xalloc(sizeof(int) * arc->height);
     if (!widths)
     {
 	xfree(points);
@@ -589,10 +589,10 @@ miFillEllipseD(
     int *widths;
     int *wids;
 
-    points = (DDXPointPtr)xalloc(sizeof(DDXPointRec) * arc->height);
+    points = xalloc(sizeof(DDXPointRec) * arc->height);
     if (!points)
 	return;
-    widths = (int *)xalloc(sizeof(int) * arc->height);
+    widths = xalloc(sizeof(int) * arc->height);
     if (!widths)
     {
 	xfree(points);
@@ -661,10 +661,10 @@ miFillArcSliceI(
     slw = arc->height;
     if (slice.flip_top || slice.flip_bot)
 	slw += (arc->height >> 1) + 1;
-    points = (DDXPointPtr)xalloc(sizeof(DDXPointRec) * slw);
+    points = xalloc(sizeof(DDXPointRec) * slw);
     if (!points)
 	return;
-    widths = (int *)xalloc(sizeof(int) * slw);
+    widths = xalloc(sizeof(int) * slw);
     if (!widths)
     {
 	xfree(points);
@@ -725,10 +725,10 @@ miFillArcSliceD(
     slw = arc->height;
     if (slice.flip_top || slice.flip_bot)
 	slw += (arc->height >> 1) + 1;
-    points = (DDXPointPtr)xalloc(sizeof(DDXPointRec) * slw);
+    points = xalloc(sizeof(DDXPointRec) * slw);
     if (!points)
 	return;
-    widths = (int *)xalloc(sizeof(int) * slw);
+    widths = xalloc(sizeof(int) * slw);
     if (!widths)
     {
 	xfree(points);
@@ -770,7 +770,7 @@ miFillArcSliceD(
  * Since we don't have to worry about overlapping segments, we can just
  * fill each arc as it comes.
  */
-_X_EXPORT void
+void
 miPolyFillArc(DrawablePtr pDraw, GCPtr pGC, int narcs, xArc *parcs)
 {
     int i;
